methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel(
'pax.plugin.pki.parhamkish.vakili.pax_player/pax_reader');
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel(
'pax.plugin.pki.parhamkish.vakili.pax_player/pax_reader');